/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- *
 * gtksourcegutterrenderer-private.h
 * This file is part of GtkSourceView
 *
 * Copyright (C) 2010 - Krzesimir Nowak
 *
 * GtkSourceView is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * GtkSourceView is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */


#ifndef __GTK_SOURCE_GUTTER_RENDERER_PRIVATE_H__
#define __GTK_SOURCE_GUTTER_RENDERER_PRIVATE_H__

#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <gtksourceview/gtksourcegutterrenderer.h>

G_BEGIN_DECLS

void _gtk_source_gutter_renderer_set_view         (GtkSourceGutterRenderer *renderer,
                                                   GtkTextView             *view,
                                                   GtkTextWindowType        window_type);

void _gtk_source_gutter_renderer_unset_view       (GtkSourceGutterRenderer *renderer);

G_END_DECLS

#endif /* __GTK_SOURCE_GUTTER_RENDERER_PRIVATE_H__ */

/* vi:ts=8 */
